==========
pyunxiao
==========
A Python library for handwritten digit recognition

Description
==========
......

Installation
===========

Download using pip via pypi

....pip install pyunxiao

Instructions for use
============
......